public class Canzone {
	/**
	 * Nome della canzone.
	 */
	private String nome;

	/**
	 * Note che compongono la canzone.
	 */
	private Nota[] note;

	/**
	 * Crea una nuova canzone.
	 * 
	 * @param nome
	 *            Nome della canzone.
	 * @param note
	 *            Note che compongono la canzone.
	 */
	public Canzone(String nome, Nota... note) {
		this.nome = nome;
		this.note = note;
	}

	/**
	 * Restituisce il nome della canzone.
	 * 
	 * @return Nome della canzone.
	 */
	public String getNome() {
		return nome;
	}

	/**
	 * Restituisce la canzone corrispondente a <code>this</code> trasportata di
	 * <code>inc<code> semitoni.
	 * 
	 * @param inc
	 *            Semitoni da ribasare.
	 * @return Canzone trasportata di <code>inc<code> semitoni.
	 */
	public Canzone getCanzoneTrasportata(int inc) {
		Nota[] noteRibasate = new Nota[note.length];
		for (int i = 0; i < note.length; i++)
			noteRibasate[i] = note[i].incrementa(inc);
		return new Canzone(nome, noteRibasate);
	}

	@Override
	public final String toString() {
		String result = getNome() + ": ";
		for (Nota nota : note)
			result += nota + " ";

		return result + "\n";
	}
}