/**
 * CLasse astratta che rappresenta una nota musicale
 * 
 * @author bioInfo
 *
 */
public abstract class Nota {
	/**
	 * Campo privato che memorizza il semitono corrispondente alla nota.
	 */
	private int semitono;

	/**
	 * Costruisce una nota corrispondente al semitono passato come parametro.
	 * 
	 * @param semitono
	 *            semitono corrispondente alla nota.
	 */
	protected Nota(int semitono) {
		if (semitono < 0 || semitono >= 12)
			throw new Error("i semitoni vanno da 0 a 11");

		this.semitono = semitono;
	}

	/**
	 * Restituisce una nota corrispondente a <code>this</code> incrementata del
	 * valore passato come parametro
	 * 
	 * @param inc
	 *            incremento da effettuare.
	 * @return la nota corrispondente a <code>incrementata</code> din
	 *         <code>inc</code> semitoni.
	 */
	public abstract Nota incrementa(int inc);

	/**
	 * Resituisce il semitono corrispondente a <code>this</code>.
	 * 
	 * @return il semitono della nota.
	 */
	public int getSemitono() {
		return semitono;
	}

	@Override
	public abstract String toString();
}